script

package
v0.1.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 19, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddIXGoUDFFromFile

func AddIXGoUDFFromFile(db *sql.DB, filename string, funcNames ...string) (err error)

AddIXGoUDFFromFile loads an .go or .xgo script from a file and registers the specified functions as UDFs in DuckDB.

func AddIXGoUDFFromSource

func AddIXGoUDFFromSource(db *sql.DB, src any, funcNames ...string) (err error)

AddIXGoUDFFromSource loads an .go or .xgo script from a source string or byte slice and registers the specified functions as UDFs in DuckDB. The filename is used for error reporting.

func EnableRegisterUDFFromSQL

func EnableRegisterUDFFromSQL(db *sql.DB) error

EnableRegisterUDFFromSQL enables the registration of user-defined functions (UDFs) from SQL. It registers a scalar UDF named "add_ixgo_udf" that allows adding more UDFs from .ixgo files directly within SQL queries. The signature of the SQL function is add_ixgo_udf(filename TEXT, funcNames TEXT...).

Types

This section is empty.

Jump to