Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddIXGoUDFFromFile ¶
AddIXGoUDFFromFile loads an .go or .xgo script from a file and registers the specified functions as UDFs in DuckDB.
func AddIXGoUDFFromSource ¶
AddIXGoUDFFromSource loads an .go or .xgo script from a source string or byte slice and registers the specified functions as UDFs in DuckDB. The filename is used for error reporting.
func EnableRegisterUDFFromSQL ¶
EnableRegisterUDFFromSQL enables the registration of user-defined functions (UDFs) from SQL. It registers a scalar UDF named "add_ixgo_udf" that allows adding more UDFs from .ixgo files directly within SQL queries. The signature of the SQL function is add_ixgo_udf(filename TEXT, funcNames TEXT...).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.